pyxmpp.interface_micro_impl.InterfaceClass

Package pyxmpp :: Module interface_micro_impl :: Class InterfaceClass |
[hide private]

# Class InterfaceClass

source code

    object --+
             |
            InterfaceClass

Instance Methods | [hide private]
__init__(self, name, bases=`(``)`, attrs=None, __doc__=None, __module__=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
providedBy(self, ob) Is the interface implemented by an object | source code
implementedBy(self, cls) Do instances of the given class implement the interface? | source code
__repr__(self) repr(x) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, name, bases=`(``)`, attrs=None, __doc__=None, __module__=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)